Function branchless::core::config::get_commit_descriptors_branches
source · Expand description
If true, show branches pointing to each commit in the smartlog.
If true, show branches pointing to each commit in the smartlog.