Enum branchless::core::eventlog::Event
source · pub enum Event {
RewriteEvent {
timestamp: f64,
event_tx_id: EventTransactionId,
old_commit_oid: MaybeZeroOid,
new_commit_oid: MaybeZeroOid,
},
RefUpdateEvent {
timestamp: f64,
event_tx_id: EventTransactionId,
ref_name: ReferenceName,
old_oid: MaybeZeroOid,
new_oid: MaybeZeroOid,
message: Option<ReferenceName>,
},
CommitEvent {
timestamp: f64,
event_tx_id: EventTransactionId,
commit_oid: NonZeroOid,
},
ObsoleteEvent {
timestamp: f64,
event_tx_id: EventTransactionId,
commit_oid: NonZeroOid,
},
UnobsoleteEvent {
timestamp: f64,
event_tx_id: EventTransactionId,
commit_oid: NonZeroOid,
},
WorkingCopySnapshot {
timestamp: f64,
event_tx_id: EventTransactionId,
head_oid: MaybeZeroOid,
commit_oid: NonZeroOid,
ref_name: Option<ReferenceName>,
},
}Expand description
An event that occurred to one of the commits in the repository.
Variants
RewriteEvent
Fields
timestamp: f64The timestamp of the event.
event_tx_id: EventTransactionIdThe transaction ID of the event.
old_commit_oid: MaybeZeroOidThe OID of the commit before the rewrite.
new_commit_oid: MaybeZeroOidThe OID of the commit after the rewrite.
Indicates that the commit was rewritten.
Examples of rewriting include rebases and amended commits.
We typically want to mark the new version of the commit as active and the old version of the commit as obsolete.
RefUpdateEvent
Fields
timestamp: f64The timestamp of the event.
event_tx_id: EventTransactionIdThe transaction ID of the event.
ref_name: ReferenceNameThe full name of the reference that was updated.
For example, HEAD or refs/heads/master.
old_oid: MaybeZeroOidThe old referent OID.
new_oid: MaybeZeroOidThe updated referent OID.
message: Option<ReferenceName>A message associated with the rewrite, if any.
Indicates that a reference was updated.
The most important reference we track is HEAD. In principle, we can also
track branch moves in this way, but Git doesn’t support the appropriate
hook until v2.29 (reference-transaction).
CommitEvent
Fields
timestamp: f64The timestamp of the event.
event_tx_id: EventTransactionIdThe transaction ID of the event.
commit_oid: NonZeroOidThe new commit OID.
Indicate that the user made a commit.
User commits should be marked as active.
ObsoleteEvent
Fields
timestamp: f64The timestamp of the event.
event_tx_id: EventTransactionIdThe transaction ID of the event.
commit_oid: NonZeroOidThe OID of the commit that was obsoleted.
Indicates that a commit was explicitly obsoleted by the user.
If the commit in question was not already active, then this has no practical effect.
UnobsoleteEvent
Fields
timestamp: f64The timestamp of the event.
event_tx_id: EventTransactionIdThe transaction ID of the event.
commit_oid: NonZeroOidThe OID of the commit that was unobsoleted.
Indicates that a commit was explicitly un-obsoleted by the user.
If the commit in question was not already obsolete, then this has no practical effect.
WorkingCopySnapshot
Fields
timestamp: f64The timestamp of the event.
event_tx_id: EventTransactionIdThe transaction ID of the event.
head_oid: MaybeZeroOidThe OID of the current HEAD commit.
commit_oid: NonZeroOidThe OID of the commit containing metadata about the working copy snapshot.
ref_name: Option<ReferenceName>The name of the checked-out branch, if any. This should be a full
reference name like refs/heads/foo.
Represents a snapshot of the working copy made at a certain time, typically before a potentially-destructive operation.
Implementations
sourceimpl Event
impl Event
sourcepub fn get_timestamp(&self) -> SystemTime
pub fn get_timestamp(&self) -> SystemTime
Get the timestamp associated with this event.
sourcepub fn get_event_tx_id(&self) -> EventTransactionId
pub fn get_event_tx_id(&self) -> EventTransactionId
Get the event transaction ID associated with this event.