Struct branchless::core::formatting::Glyphs
source · pub struct Glyphs {Show 23 fields
pub should_write_ansi_escape_codes: bool,
pub line: &'static str,
pub line_with_offshoot: &'static str,
pub vertical_ellipsis: &'static str,
pub split: &'static str,
pub merge: &'static str,
pub commit_visible: &'static str,
pub commit_visible_head: &'static str,
pub commit_obsolete: &'static str,
pub commit_obsolete_head: &'static str,
pub commit_main: &'static str,
pub commit_main_head: &'static str,
pub commit_main_obsolete: &'static str,
pub commit_main_obsolete_head: &'static str,
pub commit_omitted: &'static str,
pub commit_merge: &'static str,
pub branch_arrow: &'static str,
pub bullet_point: &'static str,
pub cycle_arrow: &'static str,
pub cycle_horizontal_line: &'static str,
pub cycle_vertical_line: &'static str,
pub cycle_upper_left_corner: &'static str,
pub cycle_lower_left_corner: &'static str,
}Expand description
Glyphs to use for rendering the smartlog.
Fields
should_write_ansi_escape_codes: boolWhether or not ANSI escape codes should be emitted (e.g. to render color).
line: &'static strLine connecting a parent commit to its single child commit.
line_with_offshoot: &'static strLine connecting a parent commit with two or more child commits.
vertical_ellipsis: &'static strDenotes an omitted sequence of commits.
split: &'static strLine used to connect a parent commit to its non-first child commit.
merge: &'static strLine used to connect a child commit to its non-first parent commit.
commit_visible: &'static strCursor for a normal visible commit which is not currently checked out.
commit_visible_head: &'static strCursor for the visible commit which is currently checked out.
commit_obsolete: &'static strCursor for an obsolete commit.
commit_obsolete_head: &'static strCursor for the obsolete commit which is currently checked out.
commit_main: &'static strCursor for a commit belonging to the main branch, which is not currently checked out.
commit_main_head: &'static strCursor for a commit belonging to the main branch, which is currently checked out.
commit_main_obsolete: &'static strCursor for an obsolete commit belonging to the main branch. (This is an unusual situation.)
commit_main_obsolete_head: &'static strCursor for an obsolete commit belonging to the main branch, which is currently checked out. (This is an unusual situation.)
commit_omitted: &'static strCursor indicating that some number of commits have been omitted from the smartlog at this position.
commit_merge: &'static strCursor indicating that a commit was either merging into this child commit or merged from this parent commit.
branch_arrow: &'static strCharacter used to point to the currently-checked-out branch.
bullet_point: &'static strBullet-point character for a list of newline-separated items.
cycle_arrow: &'static strArrow character used when printing a commit cycle.
cycle_horizontal_line: &'static strHorizontal line character used when printing a commit cycle.
cycle_vertical_line: &'static strVertical line character used when printing a commit cycle.
cycle_upper_left_corner: &'static strCorner at the upper left of the arrow used when printing a commit cycle.
cycle_lower_left_corner: &'static strCorner at the lower left of the arrow used when printing a commit cycle.
Implementations