NodeDescriptor

Trait NodeDescriptor 

pub trait NodeDescriptor {
    // Required method
    fn describe_node(
        &mut self,
        glyphs: &Glyphs,
        object: &NodeObject<'_>,
    ) -> Result<Option<StyledString>>;
}
Interface to display information about a node in the smartlog.

Required Methods

fn describe_node( &mut self, glyphs: &Glyphs, object: &NodeObject<'_>, ) -> Result<Option<StyledString>>

Provide a description of the given commit.

A return value of None indicates that this commit descriptor was inapplicable for the provided commit.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors