Struct branchless::git::ResolvedReferenceInfo
source · pub struct ResolvedReferenceInfo {
pub oid: Option<NonZeroOid>,
pub reference_name: Option<ReferenceName>,
}Expand description
A snapshot of information about a certain reference. Updates to the reference after this value is obtained are not reflected.
HEAD is typically a symbolic reference, which means that it’s a reference
that points to another reference. Usually, the other reference is a branch.
In this way, you can check out a branch and move the branch (e.g. by
committing) and HEAD is also effectively updated (you can traverse the
pointed-to reference and get the current commit OID).
There are a couple of interesting edge cases to worry about:
HEADis detached. This means that it’s pointing directly to a commit and is not a symbolic reference for the time being. This is uncommon in normal Git usage, but very common ingit-branchlessusage.HEADis unborn. This means that it doesn’t even exist yet. This happens when a repository has been freshly initialized, but no commits have been made, for example.
Fields
oid: Option<NonZeroOid>The OID of the commit that HEAD points to. If HEAD is unborn, then
this is None.
reference_name: Option<ReferenceName>The name of the reference that HEAD points to symbolically. If HEAD
is detached, then this is None.
Implementations
sourceimpl ResolvedReferenceInfo
impl ResolvedReferenceInfo
sourcepub fn get_branch_name(&self) -> Result<Option<&str>>
pub fn get_branch_name(&self) -> Result<Option<&str>>
Get the name of the branch, if any. Returns None if HEAD is
detached. The refs/heads/ prefix, if any, is stripped.