Function branchless::testing::make_git [−][src]
pub fn make_git() -> Result<GitWrapper>
Create a temporary directory for testing and a Git instance to use with it.
pub fn make_git() -> Result<GitWrapper>
Create a temporary directory for testing and a Git instance to use with it.