pub trait NodeDescriptor {
// Required method
fn describe_node(
&mut self,
glyphs: &Glyphs,
object: &NodeObject<'_>,
) -> Result<Option<StyledString>>;
}Expand description
Interface to display information about a node in the smartlog.
Required Methods
Sourcefn describe_node(
&mut self,
glyphs: &Glyphs,
object: &NodeObject<'_>,
) -> Result<Option<StyledString>>
fn describe_node( &mut self, glyphs: &Glyphs, object: &NodeObject<'_>, ) -> Result<Option<StyledString>>
Provide a description of the given commit.
A return value of None indicates that this commit descriptor was
inapplicable for the provided commit.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".