Module branchless::testing
source · Expand description
Testing utilities.
This is inside src rather than tests since we use this code in some unit
tests.
Structs
Wrapper around the Git executable, for testing.
Options for
Git::init_repo_with_options.Options for
Git::run_with_options.Represents a Git worktree for an existing Git repository on disk.
Wrapper around a
Git instance which cleans up the repository once dropped.Represents a pair of directories that will be cleaned up after this value
dropped. The two directories need to be
inited and cloneed by the
caller, respectively.Functions
Create a temporary directory for testing and a
Git instance to use with it.Create a new worktree for the provided repository.